# Generated by roxygen2: do not edit by hand

export(binary_to_liability)
export(cauchy_combined)
export(fishers_combined)
export(harmonic_combined)
export(mvmapit)
export(simulate_traits)
import(CompQuadForm)
import(Rcpp)
import(checkmate)
import(dplyr)
import(foreach)
import(harmonicmeanp)
import(mvtnorm)
import(parallel)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,pcauchy)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,sd)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(truncnorm,rtruncnorm)
importFrom(utils,head)
useDynLib(mvMAPIT)
